==> lhcsmapi-1.3.128.tar.gz: lhcsmapi-1.3.128/lhcsmapi/analysis/magnet/iqds/IqdsRqAnalysis.py <==
import numpy as np


def find_circuit_name_with_first_quenched_magnet(circuit_names, u_diode_rqd, u_diode_rqf, u_threshold=1):
    u_diode_rqd_exceed_threshold = u_diode_rqd[u_diode_rqd.values > u_threshold] # PH 01.04.2020
    t_threshold_rqd = u_diode_rqd_exceed_threshold.index[0] if len(u_diode_rqd_exceed_threshold) > 0 else np.nan # PH 01.04.2020
    u_diode_rqf_exceed_threshold = u_diode_rqf[u_diode_rqf.values > u_threshold] # PH 01.04.2020
    t_threshold_rqf = u_diode_rqf_exceed_threshold.index[0] if len(u_diode_rqf_exceed_threshold) > 0 else np.nan # PH 01.04.2020
    if t_threshold_rqd == np.nan: # PH 01.04.2020
        return '' if t_threshold_rqf == np.nan else circuit_names[1]
    if t_threshold_rqf == np.nan: # PH 01.04.2020
        return circuit_names[0]
    return circuit_names[0] if t_threshold_rqd < t_threshold_rqf else circuit_names[1]


def find_t_start_t_end_voltage_slope(u_qs0_df, u_slope_start=0.01, u_slope_end=0.1):
    u_qs0_df = abs(u_qs0_df)
    if len(u_qs0_df) < 1: # PH 31.03.2020
        return 0.0, 0.0
    t_first_max = u_qs0_df.idxmax().values[0]
    u_qs0_short_df = u_qs0_df[u_qs0_df.index < t_first_max]
    if len(u_qs0_short_df) < 1: # PH 31.03.2020
        return 0.0, 0.0
    u_qs0_short2_df = u_qs0_short_df[u_qs0_short_df < u_slope_start].dropna()
    t_slope_start = u_qs0_short2_df.index[-1] if len(u_qs0_short2_df) > 0 else u_qs0_short_df.index[0] # PH 31.03.2020
    # t_slope_start = u_qs0_short_df[u_qs0_short_df < u_slope_start].dropna().index[-1]
    u_qs0_short2_df = u_qs0_short_df[u_qs0_short_df < u_slope_end].dropna()
    t_slope_end = u_qs0_short2_df.index[-1] if len(u_qs0_short2_df) > 0 else u_qs0_short_df.index[-1] # PH 31.03.2020
    # t_slope_end = u_qs0_short_df[u_qs0_short_df < u_slope_end].dropna().index[-1]
    return t_slope_start, t_slope_end


def calculate_voltage_slope(u_qs0_aperture_df, t_slope_start, t_slope_end):
    if t_slope_start == t_slope_end: # PH 01.04.2020 singularity
        return np.nan
    u_qs0_slope_df = u_qs0_aperture_df[(u_qs0_aperture_df.index >= t_slope_start) &
                                       (u_qs0_aperture_df.index <= t_slope_end)]
    if len(u_qs0_slope_df) < 2:  # PH 01.04.2020 singularity
        return np.nan
    du_dt =  (u_qs0_slope_df.values[-1] - u_qs0_slope_df.values[0]) / (u_qs0_slope_df.index[-1] - u_qs0_slope_df.index[0])
    return float(du_dt)


def choose_u_qs0(aperture, u_qs0_int_rq_df, u_qs0_ext_rq_df):
    return u_qs0_int_rq_df if aperture == 'INT' else u_qs0_ext_rq_df

==> lhcsmapi-1.3.229.tar.gz: lhcsmapi-1.3.229/lhcsmapi/analysis/magnet/iqds/IqdsRqAnalysis.py <==
import numpy as np


def find_circuit_name_with_first_quenched_magnet(circuit_names, u_diode_rqd, u_diode_rqf, u_threshold=1):
    u_diode_rqd_exceed_threshold = u_diode_rqd[u_diode_rqd.values > u_threshold] # PH 01.04.2020
    t_threshold_rqd = u_diode_rqd_exceed_threshold.index[0] if len(u_diode_rqd_exceed_threshold) > 0 else np.nan # PH 01.04.2020
    u_diode_rqf_exceed_threshold = u_diode_rqf[u_diode_rqf.values > u_threshold] # PH 01.04.2020
    t_threshold_rqf = u_diode_rqf_exceed_threshold.index[0] if len(u_diode_rqf_exceed_threshold) > 0 else np.nan # PH 01.04.2020
    if t_threshold_rqd == np.nan: # PH 01.04.2020
        return '' if t_threshold_rqf == np.nan else circuit_names[1]
    if t_threshold_rqf == np.nan: # PH 01.04.2020
        return circuit_names[0]
    return circuit_names[0] if t_threshold_rqd < t_threshold_rqf else circuit_names[1]


def find_t_start_t_end_voltage_slope(u_qs0_df, u_slope_start=0.01, u_slope_end=0.1):
    # Remove first 10 points in order to get rid of initial spikes
    u_qs0_df = u_qs0_df[u_qs0_df.index > u_qs0_df.index[10]]
    u_qs0_df = abs(u_qs0_df)
    if len(u_qs0_df) < 1:
        return 0.0, 0.0
    t_first_max = u_qs0_df.idxmax().values[0]
    u_qs0_short_df = u_qs0_df[u_qs0_df.index < t_first_max]
    if len(u_qs0_short_df) < 1:
        return 0.0, 0.0
    u_qs0_short2_df = u_qs0_short_df[u_qs0_short_df < u_slope_start].dropna()
    t_slope_start = u_qs0_short2_df.index[-1] if len(u_qs0_short2_df) > 0 else u_qs0_short_df.index[0]
    u_qs0_short2_df = u_qs0_short_df[u_qs0_short_df < u_slope_end].dropna()
    t_slope_end = u_qs0_short2_df.index[-1] if len(u_qs0_short2_df) > 0 else u_qs0_short_df.index[-1]
    return t_slope_start, t_slope_end


def calculate_voltage_slope(u_qs0_aperture_df, t_slope_start, t_slope_end):
    if t_slope_start == t_slope_end: # PH 01.04.2020 singularity
        return np.nan
    u_qs0_slope_df = u_qs0_aperture_df[(u_qs0_aperture_df.index >= t_slope_start) &
                                       (u_qs0_aperture_df.index <= t_slope_end)]
    if len(u_qs0_slope_df) < 2:  # PH 01.04.2020 singularity
        return np.nan
    du_dt =  (u_qs0_slope_df.values[-1] - u_qs0_slope_df.values[0]) / (u_qs0_slope_df.index[-1] - u_qs0_slope_df.index[0])
    return float(du_dt)


def choose_u_qs0(aperture, u_qs0_int_rq_df, u_qs0_ext_rq_df):
    return u_qs0_int_rq_df if aperture == 'INT' else u_qs0_ext_rq_df
